@@ -58,10 +58,52 @@ class SecretManagerServiceAsyncClient:
 
     secret_path = staticmethod(SecretManagerServiceClient.secret_path)
     parse_secret_path = staticmethod(SecretManagerServiceClient.parse_secret_path)
+    secret_version_path = staticmethod(SecretManagerServiceClient.secret_version_path)
+    parse_secret_version_path = staticmethod(
+        SecretManagerServiceClient.parse_secret_version_path
+    )
+
+    common_billing_account_path = staticmethod(
+        SecretManagerServiceClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        SecretManagerServiceClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(SecretManagerServiceClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        SecretManagerServiceClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        SecretManagerServiceClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        SecretManagerServiceClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(SecretManagerServiceClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        SecretManagerServiceClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(SecretManagerServiceClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        SecretManagerServiceClient.parse_common_location_path
+    )
 
     from_service_account_file = SecretManagerServiceClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> SecretManagerServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            SecretManagerServiceTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(SecretManagerServiceClient).get_transport_class,
         type(SecretManagerServiceClient),
@@ -157,7 +199,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -261,7 +304,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, secret_id, secret]):
+        has_flattened_params = any([parent, secret_id, secret])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -349,7 +393,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, payload]):
+        has_flattened_params = any([parent, payload])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -429,7 +474,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -513,7 +559,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([secret, update_mask]):
+        has_flattened_params = any([secret, update_mask])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -583,7 +630,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -661,7 +709,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -747,7 +796,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -825,7 +875,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -848,7 +899,7 @@ class SecretManagerServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.Unknown, exceptions.ServiceUnavailable,
+                    exceptions.ServiceUnavailable, exceptions.Unknown,
                 ),
             ),
             default_timeout=60.0,
@@ -913,7 +964,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -993,7 +1045,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -1074,7 +1127,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
