@@ -58,10 +58,52 @@ class SecretManagerServiceAsyncClient:
 
     secret_path = staticmethod(SecretManagerServiceClient.secret_path)
     parse_secret_path = staticmethod(SecretManagerServiceClient.parse_secret_path)
+    secret_version_path = staticmethod(SecretManagerServiceClient.secret_version_path)
+    parse_secret_version_path = staticmethod(
+        SecretManagerServiceClient.parse_secret_version_path
+    )
+
+    common_billing_account_path = staticmethod(
+        SecretManagerServiceClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        SecretManagerServiceClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(SecretManagerServiceClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        SecretManagerServiceClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        SecretManagerServiceClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        SecretManagerServiceClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(SecretManagerServiceClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        SecretManagerServiceClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(SecretManagerServiceClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        SecretManagerServiceClient.parse_common_location_path
+    )
 
     from_service_account_file = SecretManagerServiceClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> SecretManagerServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            SecretManagerServiceTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(SecretManagerServiceClient).get_transport_class,
         type(SecretManagerServiceClient),
@@ -156,7 +198,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -260,7 +303,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, secret_id, secret]):
+        has_flattened_params = any([parent, secret_id, secret])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -348,7 +392,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, payload]):
+        has_flattened_params = any([parent, payload])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -428,7 +473,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -512,7 +558,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([secret, update_mask]):
+        has_flattened_params = any([secret, update_mask])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -582,7 +629,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -660,7 +708,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -746,7 +795,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -824,7 +874,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -847,7 +898,7 @@ class SecretManagerServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.Unknown, exceptions.ServiceUnavailable,
+                    exceptions.ServiceUnavailable, exceptions.Unknown,
                 ),
             ),
             default_timeout=60.0,
@@ -911,7 +962,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -990,7 +1042,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -1070,7 +1123,8 @@ class SecretManagerServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
